@@ -20,7 +20,7 @@ from neutron._i18n import _
 
 class RevisionConflict(n_exc.NeutronException):
     message = _('OVN revision number for %(resource_id)s (type: '
-                '%(resource_type)s) is equal or higher than the given '
+                '%(resource_type)s) is higher than the given '
                 'resource. Skipping update')
 
 
@@ -33,7 +33,6 @@ class StandardAttributeIDNotFound(n_exc.NeutronException):
 
 
 class HashRingIsEmpty(n_exc.NeutronException):
-    message = _('Hash Ring returned empty when hashing "%(key)s". All '
-                '%(node_count)d nodes were found offline. This should never '
-                'happen in a normal situation, please check the status '
-                'of your cluster')
+    message = _('Hash Ring returned empty when hashing "%(key)s". '
+                'This should never happen in a normal situation, please '
+                'check the status of your cluster')
