@@ -56,6 +56,8 @@ AddrPairsDiff = collections.namedtuple(
 
 PortExtraDHCPValidation = collections.namedtuple(
     'PortExtraDHCPValidation', ['failed', 'invalid_ipv4', 'invalid_ipv6'])
+BPInfo = collections.namedtuple(
+    'BPInfo', ['bp_param', 'vnic_type', 'capabilities'])
 
 
 class OvsdbClientCommand(object):
@@ -310,10 +312,17 @@ def is_security_groups_enabled(port):
 
 
 def validate_and_get_data_from_binding_profile(port):
+    """Validate the port binding profile
+
+    :param port: (dict) Neutron port dictionary.
+    :returns: (namedtuple BPInfo: dict, string, list) a tuple with the
+              dictionary of the port profile, the VNIC type and a list of port
+              capabilities.
+    """
     if (constants.OVN_PORT_BINDING_PROFILE not in port or
             not validators.is_attr_set(
                 port[constants.OVN_PORT_BINDING_PROFILE])):
-        return {}
+        BPInfo({}, None, [])
     param_set = {}
     param_dict = {}
     vnic_type = port.get(portbindings.VNIC_TYPE, portbindings.VNIC_NORMAL)
@@ -355,7 +364,7 @@ def validate_and_get_data_from_binding_profile(port):
         break
 
     if not param_dict:
-        return {}
+        return BPInfo({}, vnic_type, capabilities)
 
     # With this example param_set:
     #
@@ -407,7 +416,7 @@ def validate_and_get_data_from_binding_profile(port):
                     'an integer between 0 and 4095, inclusive') % tag
             raise n_exc.InvalidInput(error_message=msg)
 
-    return param_dict
+    return BPInfo(param_dict, vnic_type, capabilities)
 
 
 def is_dhcp_options_ignored(subnet):
@@ -446,8 +455,8 @@ def remove_macs_from_lsp_addresses(addresses):
     ip_list = []
     for addr in addresses:
         ip_list.extend([x for x in addr.split() if
-                       (netutils.is_valid_ipv4(x) or
-                        netutils.is_valid_ipv6(x))])
+                        (netutils.is_valid_ipv4(x) or
+                         netutils.is_valid_ipv6(x))])
     return ip_list
 
 
@@ -477,9 +486,9 @@ def get_allowed_address_pairs_ip_addresses_from_ovn_port(ovn_port):
 
 def get_ovn_port_security_groups(ovn_port, skip_trusted_port=True):
     info = {'security_groups': ovn_port.external_ids.get(
-            constants.OVN_SG_IDS_EXT_ID_KEY, '').split(),
+                constants.OVN_SG_IDS_EXT_ID_KEY, '').split(),
             'device_owner': ovn_port.external_ids.get(
-            constants.OVN_DEVICE_OWNER_EXT_ID_KEY, '')}
+                constants.OVN_DEVICE_OWNER_EXT_ID_KEY, '')}
     return get_lsp_security_groups(info, skip_trusted_port=skip_trusted_port)
 
 
@@ -844,10 +853,3 @@ def get_ovn_chassis_other_config(chassis):
         return chassis.other_config
     except AttributeError:
         return chassis.external_ids
-
-
-def get_requested_chassis(requested_chassis):
-    """Returns a list with the items in the LSP.options:requested-chassis"""
-    if isinstance(requested_chassis, str):
-        return requested_chassis.split(',')
-    return []
