@@ -37,6 +37,7 @@ import neutron.conf.db.l3_agentschedulers_db
 import neutron.conf.db.l3_dvr_db
 import neutron.conf.db.l3_gwmode_db
 import neutron.conf.db.l3_hamode_db
+import neutron.conf.experimental
 import neutron.conf.extensions.allowedaddresspairs
 import neutron.conf.extensions.conntrack_helper
 import neutron.conf.plugins.ml2.config
@@ -50,6 +51,7 @@ import neutron.conf.plugins.ml2.drivers.openvswitch.mech_ovs_conf
 import neutron.conf.plugins.ml2.drivers.ovs_conf
 import neutron.conf.quota
 import neutron.conf.service
+import neutron.conf.services.extdns_designate_driver
 import neutron.conf.services.logging
 import neutron.conf.services.metering_agent
 import neutron.conf.wsgi
@@ -75,7 +77,8 @@ AUTH_GROUPS_OPTS = {
         }
     },
     'ironic': {},
-    'placement': {}
+    'placement': {},
+    'designate': {}
 }
 
 CONF = cfg.CONF
@@ -115,6 +118,10 @@ def list_placement_auth_opts():
     return list_auth_opts('placement')
 
 
+def list_designate_auth_opts():
+    return list_auth_opts('designate')
+
+
 def list_agent_opts():
     return [
         ('agent',
@@ -157,7 +164,7 @@ def list_db_opts():
              neutron.conf.db.extraroute_db.EXTRA_ROUTE_OPTS,
              neutron.conf.db.l3_gwmode_db.L3GWMODE_OPTS,
              neutron.conf.agent.database.agentschedulers_db
-                    .AGENTS_SCHEDULER_OPTS,
+             .AGENTS_SCHEDULER_OPTS,
              neutron.conf.db.dvr_mac_db.DVR_MAC_ADDRESS_OPTS,
              neutron.conf.db.l3_dvr_db.ROUTER_DISTRIBUTED_OPTS,
              neutron.conf.db.l3_agentschedulers_db.L3_AGENTS_SCHEDULER_OPTS,
@@ -180,7 +187,7 @@ def list_opts():
          ),
         (neutron.conf.common.NOVA_CONF_SECTION,
          itertools.chain(
-              neutron.conf.common.nova_opts)
+             neutron.conf.common.nova_opts)
          ),
         (neutron.conf.common.IRONIC_CONF_SECTION,
          itertools.chain(
@@ -190,6 +197,9 @@ def list_opts():
          itertools.chain(
              neutron.conf.common.placement_opts)
          ),
+        ('designate',
+         neutron.conf.services.extdns_designate_driver.designate_opts
+         ),
         ('quotas', neutron.conf.quota.core_quota_opts)
     ]
 
@@ -342,7 +352,7 @@ def list_ovs_opts():
          neutron.conf.agent.securitygroups_rpc.security_group_opts),
         ('network_log',
          neutron.conf.services.logging.log_driver_opts),
-        ('DHCP',
+        ('dhcp',
          itertools.chain(
              neutron.conf.plugins.ml2.drivers.ovs_conf.dhcp_opts,
              neutron.conf.agent.common.DHCP_PROTOCOL_OPTS))
@@ -361,3 +371,11 @@ def list_sriov_agent_opts():
         ('agent',
          neutron.conf.agent.agent_extensions_manager.AGENT_EXT_MANAGER_OPTS)
     ]
+
+
+def list_experimental_opts():
+    return [
+        (neutron.conf.experimental.EXPERIMENTAL_CFG_GROUP,
+         itertools.chain(neutron.conf.experimental.experimental_opts)
+         ),
+    ]
