@@ -50,6 +50,11 @@ class InstanceSnapshot(object):
             session.add(self._model_class(**{col: getattr(self, col)
                                              for col in self._cols}))
 
+    def __getitem__(self, item):
+        if item not in self._cols:
+            raise KeyError(item)
+        return getattr(self, item)
+
 
 class MechanismDriverContext(object):
     """MechanismDriver context base class."""
@@ -60,6 +65,10 @@ class MechanismDriverContext(object):
         # method call of the plugin.
         self._plugin_context = plugin_context
 
+    @property
+    def plugin_context(self):
+        return self._plugin_context
+
 
 class NetworkContext(MechanismDriverContext, api.NetworkContext):
 
@@ -106,9 +115,9 @@ class SubnetContext(MechanismDriverContext, api.SubnetContext):
     def network(self):
         if self._network_context is None:
             network = self._plugin.get_network(
-                self._plugin_context, self.current['network_id'])
+                self.plugin_context, self.current['network_id'])
             self._network_context = NetworkContext(
-                self._plugin, self._plugin_context, network)
+                self._plugin, self.plugin_context, network)
         return self._network_context
 
 
@@ -127,8 +136,7 @@ class PortContext(MechanismDriverContext, api.PortContext):
         # NOTE(kevinbenton): InstanceSnapshot can go away once we are working
         # with OVO objects instead of native SQLA objects.
         self._binding = InstanceSnapshot(binding)
-        self._binding_levels = [InstanceSnapshot(l)
-                                for l in (binding_levels or [])]
+        self._binding_levels = binding_levels or []
         self._segments_to_bind = None
         self._new_bound_segment = None
         self._next_segments_to_bind = None
@@ -154,7 +162,9 @@ class PortContext(MechanismDriverContext, api.PortContext):
         self._binding_levels = []
 
     def _push_binding_level(self, binding_level):
-        self._binding_levels.append(InstanceSnapshot(binding_level))
+        # NOTE(slaweq): binding_level should be always OVO with no reference
+        # to DB object
+        self._binding_levels.append(binding_level)
 
     def _pop_binding_level(self):
         return self._binding_levels.pop()
@@ -190,9 +200,9 @@ class PortContext(MechanismDriverContext, api.PortContext):
     def network(self):
         if not self._network_context:
             network = self._plugin.get_network(
-                self._plugin_context, self.current['network_id'])
+                self.plugin_context, self.current['network_id'])
             self._network_context = NetworkContext(
-                self._plugin, self._plugin_context, network)
+                self._plugin, self.plugin_context, network)
         return self._network_context
 
     @property
@@ -240,7 +250,7 @@ class PortContext(MechanismDriverContext, api.PortContext):
         # TODO(kevinbenton): eliminate the query below. The above should
         # always return since the port is bound to a network segment. Leaving
         # in for now for minimally invasive change for back-port.
-        segment = segments_db.get_segment_by_id(self._plugin_context,
+        segment = segments_db.get_segment_by_id(self.plugin_context,
                                                 segment_id)
         if not segment:
             LOG.warning("Could not expand segment %s", segment_id)
@@ -286,7 +296,7 @@ class PortContext(MechanismDriverContext, api.PortContext):
         return self._segments_to_bind
 
     def host_agents(self, agent_type):
-        return self._plugin.get_agents(self._plugin_context,
+        return self._plugin.get_agents(self.plugin_context,
                                        filters={'agent_type': [agent_type],
                                                 'host': [self._binding.host]})
 
@@ -298,6 +308,16 @@ class PortContext(MechanismDriverContext, api.PortContext):
         self._binding.vif_details = jsonutils.dumps(vif_details)
         self._new_port_status = status
 
+    def _unset_binding(self):
+        '''Undo a previous call to set_binding() before it gets committed.
+
+        This method is for MechanismManager and is not part of the driver API.
+        '''
+        self._new_bound_segment = None
+        self._binding.vif_type = portbindings.VIF_TYPE_UNBOUND
+        self._binding.vif_details = ''
+        self._new_port_status = None
+
     def continue_binding(self, segment_id, next_segments_to_bind):
         # TODO(rkukura) Verify binding allowed, segment in network
         self._new_bound_segment = segment_id
@@ -307,8 +327,8 @@ class PortContext(MechanismDriverContext, api.PortContext):
         network_id = self._network_context.current['id']
 
         return self._plugin.type_manager.allocate_dynamic_segment(
-                self._plugin_context, network_id, segment)
+            self._plugin_context, network_id, segment)
 
     def release_dynamic_segment(self, segment_id):
         return self._plugin.type_manager.release_dynamic_segment(
-                self._plugin_context, segment_id)
+            self.plugin_context, segment_id)
